@@ -37,6 +37,7 @@ class Framer(tasking.Tasker):
 
        instance attributes
             .main = main frame when this framer is an auxiliary
+            .original = clone state, False if clone True if not clone
             .done = auxiliary completion state True or False when an auxiliary
             .elapsed = elapsed time from outline change
             .elapsedShr = share where .elapsed is stored for logging and need checks
@@ -70,6 +71,7 @@ class Framer(tasking.Tasker):
         super(Framer,self).__init__(**kw) #status = STOPPED  make runner advance so can send cmd
 
         self.main = None  #when aux framer, frame that is running this aux
+        self.original = True  # as in not a clone
         self.done = True #when aux or slave framer, completion state, set to False on enterAll
 
         self.stamp = 0.0 #beginning time to compute elapsed time since last outline change
@@ -98,12 +100,11 @@ class Framer(tasking.Tasker):
         self.frameNames = odict() #frame name registry for framer. name space of frame names
         self.frameCounter = 0 #frame name registry counter for framer
 
-    def clone(self, index, clones):
-        """ Return clone of self with name derived from index
-            Assumes that Framer Registry as been assigned to self.store.house
+    def clone(self, name, period=0.0, schedule=AUX):
+        """ Return clone of self named name
 
         """
-        name = "{0}_{1:d}".format(self.name, index)
+        self.store.house.assignRegistries() # ensure Framer.names is houses registry
 
         if name and not REO_IdentPub.match(name):
             msg = "CloneError: Invalid framer name '{0}'.".format(name)
@@ -113,27 +114,21 @@ class Framer(tasking.Tasker):
             msg = "CloneError: Framer '{0}' already exists.".format(name)
             raise excepting.CloneError(msg)
 
-        clone = Framer(name=name, store=self.store, period=0.0)
-        console.profuse("     Cloning framer {0} to {1}\n".format(self.name, clone.name))
-        clone.schedule = AUX
-        clone.first = self.first.name # resolve later
-        clones[self.name] = (self, clone)
+        clone = Framer(name=name,
+                       store=self.store,
+                       period=period,
+                       schedule=schedule)
+        console.profuse("     Cloning Framer original '{0}' to clone '{1}'\n"
+                        "".format(self.name, clone.name))
+        clone.schedule = schedule
+        clone.first = self.first # resolve later
 
+        clone.assignFrameRegistry() #Frame.names is cloned framer registry
         for frame in self.frameNames.values():
-            for aux in frame.auxes:
-                aux.clone(index, clones) # changes clones in place
+            frame.clone(framer=clone)
 
         return clone
 
-    def cloneFrames(self, clone, clones):
-        """ Return clone of self with name derived from index
-            Assumes that Framer Registry as been assigned to self.store.house
-
-        """
-        clone.assignFrameRegistry()
-        for frame in self.frameNames.values():
-            frame.clone(framer=clone, clones=clones) #creates cloned frames in cloned framer registry
-
     def assignFrameRegistry(self):
         """Point Frame class name registry dict and counter to .frameNames
            and .frameCounter.
@@ -208,11 +203,7 @@ class Framer(tasking.Tasker):
 
         #Resolve first frame link
         if self.first:
-            if not isinstance(self.first, Frame):
-                if self.first not in Frame.Names:
-                    raise excepting.ResolveError("Bad first frame link", self.name, self.first)
-
-                self.first = Frame.Names[self.first] #replace link name with link
+            self.first = resolveFrame(self.first, who=self.name, desc='first')
         else:
             raise excepting.ResolveError("No first frame link", self.name, self.first)
 
@@ -367,7 +358,7 @@ class Framer(tasking.Tasker):
             if frame.precur(): #transition or cond aux was successful so stop evaluating
                 return True
 
-    def exitAll(self):
+    def exitAll(self, abort=False):
         """sets exits to .actives and reverses so in bottom up order
            calls exitActions for frames in exits list
 
@@ -380,10 +371,10 @@ class Framer(tasking.Tasker):
             self.name))
 
         exits = self.actives[:]  #make copy of self.actives so can reverse it
-        #exits.reverse() #reverse (in place)  so in bottom up order
         self.exit(exits) #exits is reversed in place in exit()
         self.deactivate()
-        self.done = True
+        if not abort:
+            self.done = True
 
     def exit(self, exits = []):
         """calls exitActions for frames in exits list
@@ -548,7 +539,8 @@ class Framer(tasking.Tasker):
                             self.name,self.active.name,self.store.stamp)
                         self.desire = STOP
                         console.terse(msg)
-                        self.exitAll()  #self.desire may change, self.done = True set in exitAll()
+                        #self.done = False set in exitAll(abort=True) when abort == True
+                        self.exitAll(abort=True)  #self.desire may change,
                         console.profuse("   Stopped Framer '{0}'\n".format(self.name))
                         self.status = STOPPED
 
@@ -572,6 +564,7 @@ class Framer(tasking.Tasker):
                         msg = "   Aborting %s in %s at %0.3f\n" %\
                             (self.name, self.active.name, self.store.stamp)
                         console.terse(msg)
+                        self.exitAll()  #self.desire may change, self.done = True set in exitAll()
                     elif status == STOPPED or status == READIED:
                         msg = "   Aborting %s at %0.3f\n" %\
                             (self.name, self.store.stamp)
@@ -686,7 +679,7 @@ class Frame(registering.StoriedRegistry):
         self.head = [] #list of frames from top down to self
         self.human = '' #string of names of frames in outline '>' separated
         self.headHuman = '' #string of names of frames in head '>' separated
-        self.next = None #next frame used by builder for transitions to next
+        self.next_ = None #next frame used by builder for transitions to next
 
         self.beacts = [] #list of enter need acts callables that return True or False
         self.preacts = [] #list of pre-recurring acts  callables upon pre recurrence
@@ -698,62 +691,59 @@ class Frame(registering.StoriedRegistry):
 
         self.auxes = [] #list of auxilary framers for this frame
 
-    def clone(self, framer, clones):
+    def clone(self, framer):
         """ Return clone of self by creating new frame in framer and by
             frame links, acts, and auxes
-            clones is dict with items each key is name of orignal framer and value
-                 is duple of (original, clone) framer references
 
-            Assumes that the Frame Registry is pointing to framer which is a clone
-            of this Frame's Framer so all new Frames will be in the cloned registry.
+            Assumes that the Frame Registry is pointing to framer
+            which is a clone of this Frame's Framer
+            so all new Frames will be in the cloned registry.
 
         """
-        clone = Frame(  name=self.name,
-                        store=self.store,
-                        framer=framer)
-        console.profuse("     Cloning frame {0} into framer {1}\n".format(
+        clone = Frame(name=self.name,
+                      store=self.store,
+                      framer=framer)
+        console.profuse("       Cloning Frame '{0}' into Framer '{1}'\n".format(
                                clone.name, framer.name))
 
+        for aux in self.auxes:
+            clone.addAux(aux)
+
         if self.over:
             if isinstance(self.over, Frame):
-                clone.over = self.over.name
-            else:
-                clone.over = self.over
-        if self.next:
-            if isinstance(self.next, Frame):
-                clone.next = self.next.name
-            else:
-                clone.next = self.next
+                msg = ("CloneError: Attempting to clone resolved over frame"
+                      "  '{0}'.".format(self.over.name))
+                raise excepting.CloneError(msg)
+            clone.over = self.over
+
+        if self.next_:
+            if isinstance(self.next_, Frame):
+                msg = ("CloneError: Attempting to clone resolved next frame"
+                      "  '{0}'.".format(self.next_.name))
+                raise excepting.CloneError(msg)
+            clone.next_ = self.next_
 
         for under in self.unders:
             if isinstance(under, Frame):
-                clone.unders.append(under.name)
-            else:
-                clone.unders.append(under)
-
-        for i, aux in enumerate(self.auxes): #replace each aux with its clone name
-            if isinstance(aux, Framer):
-                if aux.name in clones:
-                    self.auxes[i] = clones[aux.name][1].name
-            else: # assume namestring
-                if aux in clones:
-                    self.auxes[i] = clones[aux][1].name
+                msg = ("CloneError: Attempting to clone resolved under frame"
+                      "  '{0}'.".format(under.name))
+                raise excepting.CloneError(msg)
+            clone.unders.append(under)
 
         for act in self.beacts:
-            clone.addBeact(act.clone(clones))
+            clone.addBeact(act.clone()) # sets context and frame name
         for act in self.preacts:
-            clone.addPreact(act.clone(clones))
+            clone.addPreact(act.clone())
         for act in self.enacts:
-            clone.addEnact(act.clone(clones))
+            clone.addEnact(act.clone())
         for act in self.renacts:
-            clone.addRenact(act.clone(clones))
+            clone.addRenact(act.clone())
         for act in self.reacts:
-            clone.addReact(act.clone(clones))
+            clone.addReact(act.clone())
         for act in self.exacts:
-            clone.addExact(act.clone(clones))
+            clone.addExact(act.clone())
         for act in self.rexacts:
-            clone.addRexact(act.clone(clones))
-
+            clone.addRexact(act.clone())
 
         return clone
 
@@ -835,14 +825,8 @@ class Frame(registering.StoriedRegistry):
         """Resolve next link
 
         """
-        if self.next:
-            if not isinstance(self.next, Frame): #over is name not ref so resolve
-                try:
-                    next = Frame.Names[self.next] #get reference from Frame name registry
-                except KeyError:
-                    raise excepting.ResolveError("Bad next link in outline", self.name, self.next)
-
-                self.next = next
+        if self.next_:
+            self.next_ = resolveFrame(self.next_, who=self.name, desc='next')
 
     def resolveOverLinks(self):
         """Starting with self.over climb over links resolving the links as needed along the way
@@ -883,42 +867,34 @@ class Frame(registering.StoriedRegistry):
     def resolveUnderLinks(self):
         """ Resolve under links """
         for i, under in enumerate(self.unders):
-            if not isinstance(under, Frame):
-                try:
-                    self.unders[i] = Frame.Names[under] #replace link name with link
-                except KeyError:
-                    raise excepting.ResolveError("Bad link in unders", self.name, under)
+            self.unders[i] = resolveFrame(under, who=self.name, desc='under')
 
-        #maybe should as precaution check for and remove duplicate unders
-        #with right most removed
-        #or at least check for duplicates and flag error
+        if len(set(self.unders)) != len(self.unders): # duplicates
+            raise excepting.ResolveError("Duplicate under", name=self.name, value=self.unders)
 
     def resolveAuxLinks(self):
-        """ Resolve aux links """
+        """ Resolve aux links
+
+            If aux.original
+               aux.main for each aux is not assigned here but is assigned when
+              frame.enter before aux.enterAll() so can reuse aux in other frames.
+            Otherwise
+               assign aux.main to self
+        """
         for i, aux in enumerate(self.auxes):
-            if not isinstance(aux, Framer): # link is name not object
-                if aux not in Framer.Names:
-                    raise excepting.ResolveError("ResolveError: Bad aux(s) link name", self.name, aux)
-                aux = Framer.Names[aux] #replace link name with link
-                if not isinstance(aux, Framer): #maker sure framer not just tasker since tasker framer share registry
-                    raise excepting.ResolveError("ResolveError: Bad aux(s) name, tasker not framer", self.name, aux.name)
-                self.auxes[i] = aux #replace link name with link
-
-            if aux.schedule != AUX:
-                raise excepting.ResolveError("ResolveError: Scheduling context not aux", aux.name, aux.schedule)
-
-            #aux.main  is set upon frame.enter before aux.enterAll() so can reuse aux in other frames
+            self.auxes[i] = aux = resolveFramer(aux,
+                                                who=self.name,
+                                                desc='aux',
+                                                contexts=[AUX])
+            if not aux.original: # clones get fixed main never released
+                aux.main = self
 
     def resolveFramerLink(self):
         """Resolve framer link """
         if self.framer:
-            if not isinstance(self.framer, Framer):
-                if self.framer not in Framer.Names:
-                    raise excepting.ResolveError("ResolveError: Bad framer link name", self.name, self.framer)
-                framer = Framer.Names[self.framer] #replace link name with link
-                if not isinstance(framer, Framer):  #maker sure framer not tasker since tasker framer share registry
-                    raise excepting.ResolveError("ResolveError: Bad framer name, tasker not framer", self.name, framer.name)
-                self.framer = framer #replace link name with link
+            self.framer = framer = resolveFramer(self.framer,
+                                                who=self.name,
+                                                desc='framer',)
 
     def resolve(self):
         """Resolve links where links are instance name strings assigned during building
@@ -934,6 +910,8 @@ class Frame(registering.StoriedRegistry):
         self.resolveOverLinks()
         self.resolveUnderLinks()
 
+        self.resolveAuxLinks()
+
         for act in self.beacts:
             act.resolve()
 
@@ -955,7 +933,7 @@ class Frame(registering.StoriedRegistry):
         for act in self.renacts:
             act.resolve()
 
-        self.resolveAuxLinks()
+
 
     def findBottom(self):
         """Finds the bottom most frame for outline that this frame lives in
@@ -1073,8 +1051,9 @@ class Frame(registering.StoriedRegistry):
         for aux in self.auxes:
             #if aux.main is not None then it has not been released and so
             #we can't enter unless its ourself for forced re-entry
-            if aux.main and (aux.main is not self): #see if aux still belongs to another frame
-                console.profuse("    False aux {0}.main in use".format(aux.name))
+            if aux.main and (aux.main is not self): # does aux belong to another frame
+                console.profuse("    False. Invalid aux {0} in use "
+                        "by another frame {1}".format(aux.name, aux.main.name))
                 return False
 
             if not aux.checkStart(): #performs entry checks beacts
@@ -1095,8 +1074,8 @@ class Frame(registering.StoriedRegistry):
         for aux in self.auxes:
             msg = "To: %s<%s at %s\n" % (aux.name, aux.first.human, aux.store.stamp)
             console.terse(msg)
-
-            aux.main = self  #assign aux's main to this frame
+            if aux.original:
+                aux.main = self  #assign aux's main to this frame
             aux.enterAll() #starts at aux.first frame
 
     def renter(self):
@@ -1160,7 +1139,8 @@ class Frame(registering.StoriedRegistry):
 
         for aux in self.auxes: #since auxes entered last must be exited first
             aux.exitAll()
-            aux.main = None #release aux to be used by another frame
+            if aux.original:
+                aux.main = None #release aux to be used by another frame
 
         for act in self.exacts:
             act() #call Exit Action
@@ -1251,30 +1231,62 @@ class Frame(registering.StoriedRegistry):
 
 
 #utility functions
-def resolveFramer(framer, who=''):
+def resolveFramer(framer, who='', desc='framer', contexts=None,
+                  human='', count=None):
     """ Returns resolved framer instance from framer
         framer may be name of framer or instance
-        who is optinal name of object owning the link such as framer or frame
-        Framer.Names registry must be setup
+        who is optional name of object owning the link
+        such as framer or frame or actor
+        desc is string description of framer link such as 'aux' or 'framer'
+        contexts is list of allowed schedule contexts, None or empty means any.
+        human is human readable version of associated declaration
+        cout is line number of associated declaration
+
+        Framer.Names registry must already be setup
     """
     if not isinstance(framer, Framer): # not instance so name
         if framer not in Framer.Names:
-            raise excepting.ResolveError("ResolveError: Bad framer link name", framer, who)
+            raise excepting.ResolveError("ResolveError: Bad {0} link name".format(desc),
+                                         framer,
+                                         who,
+                                         human,
+                                         count)
         framer = Framer.Names[framer]
-
+        #maker sure framer not just tasker since tasker framer share registry
+        if not isinstance(framer, Framer):
+            raise excepting.ResolveError("ResolveError: Bad {0} link name, tasker"
+                                         " not framer".format(desc),
+                                         self.name,
+                                         aux.name,
+                                         human,
+                                         count)
+        if contexts and framer.schedule not in contexts:
+            raise excepting.ResolveError("ResolveError: Bad {0} link not scheduled"
+                                         " as one of {1}".format(desc,
+                                            [ScheduleNames.get(context, context)
+                                                 for context in contexts]),
+                                         framer.name,
+                                         who,
+                                         human,
+                                         count)
+        console.terse("    Resolved {0} as {1} in {2}".format(desc, framer.name, who))
     return framer
 
 ResolveFramer = resolveFramer
 
-def resolveFrame(frame, who=''):
+def resolveFrame(frame, who='', desc='act', human='', count=None):
     """ Returns resolved frame instance from frame
-            frame may be name of frame or instance
+        frame may be name of frame or instance
 
-            Frame.Names registry must be setup
-        """
+        Frame.Names registry must be setup
+    """
     if not isinstance(frame, Frame): # not instance so name
         if frame not in Frame.Names:
-            raise excepting.ResolveError("ResolveError: Bad frame link name", frame, who)
+            raise excepting.ResolveError("ResolveError: Bad {0} frame link name".format(desc),
+                                         frame,
+                                         who,
+                                         human,
+                                         count)
         frame = Frame.Names[frame] #replace frame name with frame
 
     return frame
