@@ -66,8 +66,11 @@ class House(registering.StoriedRegistry):
           .backs = list of taskables to go in back of taskables
 
           .taskables = list of active/inactive taskers (fronts + mids + backs)
-          .auxes = list of aux  taskers in house subset of .taskers
-          .slaves = list of slave frameworks in house subset of .taskers
+          .auxes = list of aux  framers in house subset of .taskers
+          .slaves = list of slave taskers in house subset of .taskers
+          .moots = list of moot framers in house subset of .taskers
+
+          .clones = list of tuples for cloning (original, clone, human, count)
 
           .names = dictonary of names from each name registry
           .counters = dictionary of counters from each name registry
@@ -92,6 +95,9 @@ class House(registering.StoriedRegistry):
         self.taskables = [] #list taskable (active inactive) taskers (fronts + mids + backs)
         self.auxes = [] #list of aux framers in house
         self.slaves = [] #list of slave taskers in house
+        self.moots = [] #list of moot framers in house
+
+        self.clones = [] # list of tuples of clone pair names (original, clone, human, count)
 
         self.names = odict() #houses dict of registry Names
         self.counters = odict() #houses dict of registry Name Counters
@@ -116,6 +122,7 @@ class House(registering.StoriedRegistry):
     def assignRegistries(self):
         """Point class Names registries dicts and counters to local version in house
            Subsequent creation of instances will then be registered locally
+           Idempotent operation
         """
         for key, value in Registries.items():
             value.Names = self.names[key]
@@ -128,21 +135,48 @@ class House(registering.StoriedRegistry):
         """
         console.terse("   Resolving House '{0}' ...\n".format(self.name))
         self.assignRegistries()
-
-        for tasker in self.taskers:
+        self.resolveClones()
+        for tasker in [tasker for tasker in self.taskers if tasker not in self.moots]:
             tasker.resolve()
 
+    def resolveClones(self):
+        """ resolves clone dyad  tuples of form (original, clone, human, count)
+            creates clone and adds to taskables
+            resolution looks up name string in appropriate registry and replaces
+            name string with link to object
+        """
+        console.terse("     Resolving clones for House '{0}' ...\n".format(self.name))
+
+        for original, clone, human, count in self.clones:
+            console.concise("       Cloning original '{0}' as '{1}'\n"
+                            "".format(original, clone))
+            original = framing.resolveFramer(original,
+                                             who=self.name,
+                                             desc='original',
+                                             contexts=[MOOT],
+                                             human=human,
+                                             count=count)
+            clone = original.clone(name=clone, schedule=AUX)
+            clone.original = False  # main frame will be fixed
+            self.taskers.append(clone)
+            self.framers.append(clone)
+            self.auxes.append(clone)
+
+            console.profuse("     Cloned original '{0}' as '{1}'\n".format(
+                   original.name, clone.name))
+
+
     def traceOutlines(self):
         """ trace and assign outlines for each frame
         """
-        console.terse("   Tracing outlines for house {0}\n".format(self.name))
+        console.terse("   Tracing outlines for House {0}\n".format(self.name))
         self.assignRegistries()
 
         for framer in self.framers:
             framer.traceOutlines()
 
     def showAllTaskers(self):
-        """Show all Taskers and Slaves and Auxes and Framers."""
+        """Show all Taskers and Slaves and Auxes and Moots and Framers."""
 
         console.terse("Taskables in House '{0}':\n     {1}\n".format(
             self.name, ' '.join([tasker.name for tasker in self.taskables])))
@@ -153,10 +187,31 @@ class House(registering.StoriedRegistry):
         console.terse("Auxes in House '{0}':\n     {1}\n".format(
             self.name, ' '.join([tasker.name for tasker in self.auxes])))
 
+        console.terse("Moots in House '{0}':\n     {1}\n".format(
+                    self.name, ' '.join([tasker.name for tasker in self.moots])))
+
         console.terse("Framers in House '{0}':\n     {1}\n".format(
             self.name, ' '.join([tasker.name for tasker in self.framers])))
 
-    def cloneFramer(self, framer, index):
+    def cloneFramer(self, original, name):
+        """
+        Create a clone named name of Framer original and return
+        """
+        self.assignRegistries()
+
+        clone.resolveLinks() # resolve links in clone
+        clone.traceOutlines()  # traceoutlines in clone
+        self.taskers.append(clone)
+        self.framers.append(clone)
+        self.auxes.append(clone)
+
+        console.profuse("     Cloned framer '{0}' as '{1}' in House "
+                "'{2}'\n".format(framer.name, clone.name, self.name))
+
+        return clonee # return primary clone of framer
+
+
+    def cloneFramerOld(self, framer, index):
         """ Create a clone of framer framer with name generated from index
                 as aux framer and return
         """
