@@ -70,6 +70,19 @@ class NeedAlways(Need):
 
 class NeedDone(Need):
     """NeedDone Need Special Need"""
+    def resolve(self, tasker, **kwa):
+        """Resolves value (tasker) link that is passed in as tasker parm
+           resolved link is passed back to container act to update in act's parms
+        """
+        parms = super(NeedDone, self).resolve( **kwa)
+        parms['tasker'] = tasker = tasking.resolveTasker(tasker,
+                                                         who=self.name,
+                                                         desc='need done tasker',
+                                                         contexts=[],
+                                                         human=self.act.human,
+                                                         count=self.act.count)
+        return parms #return items are updated in original act parms
+
     def action(self, tasker, **kw):
         """
         Check if  tasker done
@@ -81,51 +94,22 @@ class NeedDone(Need):
 
         return result
 
-    def resolve(self, tasker, **kwa):
-        """Resolves value (tasker) link that is passed in as tasker parm
-           resolved link is passed back to container act to update in act's parms
-        """
-        parms = super(NeedDone, self).resolve( **kwa)
-
-        if not isinstance(tasker, tasking.Tasker): # name of tasker so resolve
-            if tasker not in tasking.Tasker.Names:
-                raise excepting.ResolveError("ResolveError: Bad need done aux link", tasker, self.name)
-            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
-
-        #if not tasker.schedule in [AUX, SLAVE]:
-            #raise excepting.ResolveError("ResolveError: Bad need done tasker not auxiliary or slave", tasker, self.name)
-
-        parms['tasker'] = tasker #replace name with valid link
-
-        return parms #return items are updated in original act parms
-
-    def cloneParms(self, parms, clones, **kw):
-        """ Returns parms fixed up for framing cloning. This includes:
-            Reverting any Frame links to name strings,
-            Reverting non cloned Framer links into name strings
-            Replacing any cloned framer links with the cloned name strings from clones
-            Replacing any parms that are acts with clones.
-
-            clones is dict whose items keys are original framer names
-            and values are duples of (original,clone) framer references
-        """
-        parms = super(NeedStatus,self).cloneParms(parms, clones, **kw)
-
-        tasker = parms.get('tasker')
-
-        if isinstance(tasker, tasking.Tasker):
-            if tasker.name in clones:
-                parms['tasker'] = clones[tasker.name][1].name
-            else:
-                parms['tasker'] = tasker.name # revert to name
-        elif tasker: # assume namestring
-            if tasker in clones:
-                parms['tasker'] = clones[tasker][1].name
-
-        return parms
-
 class NeedStatus(Need):
     """NeedStatus Need Special Need """
+
+    def resolve(self, tasker, **kwa):
+        """Resolves value (tasker) link that is passed in as parm
+           resolved link is passed back to container act to update in act's parms
+        """
+        parms = super(NeedStatus, self).resolve( **kwa)
+        parms['tasker'] = tasker = tasking.resolveTasker(tasker,
+                                                         who=self.name,
+                                                         desc='need status tasker',
+                                                         contexts=[],
+                                                         human=self.act.human,
+                                                         count=self.act.count)
+        return parms #return items are updated in original act parms
+
     def action(self, tasker, status, **kw):
         """
         Check if  tasker done
@@ -140,51 +124,53 @@ class NeedStatus(Need):
 
         return result
 
-    def resolve(self, tasker, **kwa):
-        """Resolves value (tasker) link that is passed in as parm
-           resolved link is passed back to container act to update in act's parms
+
+class NeedState(Need):
+    """
+    NeedState is a base class for Needs that must resolve a state share ref
+    """
+    def resolve(self, state, stateField, **kwa):
         """
-        parms = super(NeedStatus, self).resolve( **kwa)
+        Resolves state share
 
-        if not isinstance(tasker, tasking.Tasker): #so name of tasker
-            if tasker not in tasking.Tasker.Names:
-                raise excepting.ResolveError("ResolveError: Bad need done tasker link", tasker, self.name)
-            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
+        parms:
+            state       share path of state
+            stateField  state share field name
+        """
+        parms = super(NeedState, self).resolve( **kwa)
 
-        parms['tasker'] = tasker #replace name with valid link
+        #convert state path to share and create field if necessary
+        parms['state'] = state = self.resolvePath(ipath=state,
+                                                  warn=True) # now a share
+
+        if not stateField: #default rules for field
+            if state: #state has fields
+                if 'value' in state:
+                    stateField = 'value'
+
+                else: #ambiguous
+                    msg = ("ResolveError: Can't determine field for state"
+                          " '{0}'".format(state.name))
+                    raise excepting.ResolveError(msg, 'state', self.name,
+                                            self.act.human, self.act.count)
+            else:
+                stateField = 'value'
+
+        if stateField not in state:
+            console.profuse("     Warning: Non-existent field '{0}' in state {1}"
+                            " ... creating anyway".format(stateField, state.name))
+            state[stateField] = 0.0 #create
+
+        parms['stateField'] = stateField
 
         return parms #return items are updated in original act parms
 
-    def cloneParms(self, parms, clones, **kw):
-        """ Returns parms fixed up for framing cloning. This includes:
-            Reverting any Frame links to name strings,
-            Reverting non cloned Framer links into name strings
-            Replacing any cloned framer links with the cloned name strings from clones
-            Replacing any parms that are acts with clones.
-
-            clones is dict whose items keys are original framer names
-            and values are duples of (original,clone) framer references
-        """
-        parms = super(NeedStatus,self).cloneParms(parms, clones, **kw)
-
-        tasker = parms.get('tasker')
-
-        if isinstance(tasker, tasking.Tasker):
-            if tasker.name in clones:
-                parms['tasker'] = clones[tasker.name][1].name
-            else:
-                parms['tasker'] = tasker.name # revert to name
-        elif tasker: # assume namestring
-            if tasker in clones:
-                parms['tasker'] = clones[tasker][1].name
-
-        return parms
-
-class NeedBoolean(Need):
+class NeedBoolean(NeedState):
     """NeedBoolean Need Special Need
 
        if state
     """
+
     def action(self, state, stateField, **kw):
         """ Check if state[stateField] evaluates to True
             parameters:
@@ -201,7 +187,7 @@ class NeedBoolean(Need):
 
         return result
 
-class NeedDirect(Need):
+class NeedDirect(NeedState):
     """NeedDirect Need
 
        if state comparison goal [+- tolerance]
@@ -217,19 +203,54 @@ class NeedDirect(Need):
                 tolerance
 
         """
-
         result = self.Check(state[stateField], comparison, goal, tolerance)
         console.profuse("Need Direct, if {0}[{1}] {2} {3} +- {4}: = {5}\n".format(
             state.name, stateField, comparison, goal, tolerance, result))
 
         return result
 
-class NeedIndirect(Need):
+class NeedIndirect(NeedState):
     """NeedIndirect Need
 
        if state comparison goal [+- tolerance]
     """
-    def action(self, state, stateField, comparison, goal, goalField, tolerance, **kw):
+    def resolve(self, goal, goalField, **kwa):
+        """
+        Resolves state share
+
+        parms:
+            comparison  comparison operator string
+            goal        share path of goal
+            goalField   goal share field name
+            tolerance   tolerance value
+
+        """
+        parms = super(NeedIndirect, self).resolve( **kwa)
+
+        #convert goal path to share and create field if necessary
+        parms['goal'] = goal = self.resolvePath(ipath=goal,
+                                                warn=True) # now a share
+
+        if not goalField: #default rules for field
+            if goal: #goal has fields
+                if 'value' in goal:
+                    goalField = 'value'
+
+                else: #use stateField
+                    goalField = stateField
+            else:
+                goalField = 'value'
+
+        if goalField not in goal:
+            console.profuse("     Warning: Non-existent field '{0}' in goal"
+                    " {1} ... creating anyway".format(goalField, goal.name))
+            goal[goalField] = 0.0 #create
+
+        parms['goalField'] = goalField
+
+        return parms #return items are updated in original act parms
+
+    def action(self, state, stateField, comparison, goal, goalField, tolerance, **kwa):
         """ Check if state[field] comparison to goal[goalField] +- tolerance is True
                        parameters:
               state = share of state
@@ -267,11 +288,11 @@ class NeedMarker(Need):
         """
         parms = super(NeedMarker, self).resolve( **kwa)
 
-        if not isinstance(frame, framing.Frame): # must be pathname
-            if frame not in framing.Frame.Names:
-                msg = "ResolveError: Bad need update frame link"
-                raise excepting.ResolveError(msg, frame, self.name)
-            parms['frame'] = frame = framing.Frame.Names[frame] #replace frame name with frame
+        parms['frame'] = frame = framing.resolveFrame(frame,
+                                                      who=self.name,
+                                                      desc='need marker')
+        parms['share'] = share = self.resolvePath(ipath=share,
+                                                  warn=True) # now a share
 
         if not share.marks.get(frame.name):
             share.marks[frame.name] = storing.Mark()
@@ -288,12 +309,15 @@ class NeedMarker(Need):
         if not found:
             if marker not in acting.Actor.Registry:
                 msg = "ResolveError: Bad need marker link"
-                raise excepting.ResolveError(msg, marker, self.name)
+                raise excepting.ResolveError(msg, marker, self.name,
+                                self.act.human, self.act.count)
 
             markerParms = dict(share=share, frame=frame.name)
             parms['marker'] = marker = acting.Act(  actor=marker,
                                                     registrar=acting.Actor,
-                                                    parms=markerParms)
+                                                    parms=markerParms,
+                                                    human=self.act.human,
+                                                    count=self.act.count)
 
             frame.insertEnact(marker)
             console.profuse("     Added {0} {1} with {2} in {3}\n".format(
@@ -305,28 +329,6 @@ class NeedMarker(Need):
 
         return parms #return items are updated in original act parms
 
-    def cloneParms(self, parms, clones, **kw):
-        """ Returns parms fixed up for framing cloning. This includes:
-            Reverting any Frame links to name strings,
-            Reverting non cloned Framer links into name strings
-            Replacing any cloned framer links with the cloned name strings from clones
-            Replacing any parms that are acts with clones.
-
-            clones is dict whose items keys are original framer names
-            and values are duples of (original,clone) framer references
-        """
-        parms = super(NeedMarker,self).cloneParms(parms, clones, **kw)
-
-        share = parms.get('share')
-        name = parms.get('name')
-        frame = parms.get('frame')
-        marker = parms.get('marker')
-
-        if isinstance(frame, framing.Frame):
-            parms['frame'] = frame.name # revert to name
-
-        return parms
-
 class NeedUpdate(NeedMarker):
     """ NeedUpdate Need Special Need """
     def action(self, share, frame, **kw):
