@@ -25,7 +25,7 @@ from . import storing
 from . import tasking
 from . import building
 
-from .. import __version__
+from ..__metadata__ import __version__
 
 from .consoling import getConsole
 console = getConsole()
@@ -147,6 +147,8 @@ class Skedder(object):
                 ("behaviors", "meta.behaviors", odict(value=self.behaviors)),
                 ("credentials", "meta.credentials",
                      odict([('username', self.username), ('password', self.password)])),
+                ("failure", "meta.failure", odict(value="")),
+                ("framers", "meta.framers", odict()),
             ]
         if metas:
             self.metas.extend(metas)
@@ -334,7 +336,6 @@ class Skedder(object):
                 house.store.expose(values=(console._verbosity >= console.Wordage.terse))
 
 
-
 def Test(real = False, verbose = False):
     """Module Common self test
 
