@@ -35,7 +35,7 @@ class Tasker(registering.StoriedRegistry):
         """Initialize instance.
 
            iherited instance attributes
-           .name = unique name for machine
+           .name = unique name for tasker
            .store = data store
 
            instance attributes
@@ -64,12 +64,11 @@ class Tasker(registering.StoriedRegistry):
         self.desire = STOP #desired control next time Task is iterated
         self.done = True # tasker completion state reset on restart
         self.schedule = schedule #initial scheduling context vis a vis skedder
-
         self.runner = None #reference to runner generator
         self.remake() #make generator assign to .runner and advance to yield
 
-        self.source = None # future reference to share
-        self.sourceFields = None #future reference to share fields
+        #self.source = None # future reference to share
+        #self.sourceFields = None #future reference to share fields
 
     def reinit(self, period=None, schedule=None, **kw):
         if period is not None:
@@ -203,79 +202,31 @@ class Tasker(registering.StoriedRegistry):
             self.status = ABORTED
 
 
-def Test(real = False, verbose = False):
-    """Module Common self test
-
+def resolveTasker(tasker, who='', desc='tasker', contexts=None, human='', count=None):
+    """ Returns resolved tasker instance from tasker
+        tasker may be name of tasker or instance
+        who is optional name of object owning the link
+        such as framer or frame or actor
+        desc is string description of tasker link such as 'aux' or 'framer'
+        contexts is list of allowed schedule contexts, None or empty means any.
+        Taskers.Names registry must already be setup
     """
+    if not isinstance(tasker, Tasker): # not instance so name
+        if tasker not in Tasker.Names:
+            raise excepting.ResolveError("ResolveError: Bad {0} link name".format(desc),
+                                         tasker,
+                                         who,
+                                         human,
+                                         count)
+        tasker = Tasker.Names[tasker]
+        if contexts and tasker.schedule not in contexts:
+            raise excepting.ResolveError("ResolveError: Bad {0} link not scheduled"
+                                         " as one of {1}".format(desc, contexts),
+                                         tasker.name,
+                                         who,
+                                         human,
+                                         count)
+        console.terse("    Resolved {0} as {1} in {2}".format(desc, tasker.name, who))
+    return tasker
 
-    import housing
-    reload(housing)
-    import skedding
-
-    housing.ClearRegistries()
-
-    print(housing.Registries)
-    print("")
-    print(housing.Registries["tasker"].Names)
-    print(housing.Registries["tasker"].Counter)
-    print("")
-
-    house = housing.House()
-
-    t1 = Tasker(name = 't1', store = house.store)
-    t2 = Tasker(name = 't2', store = house.store)
-    t3 = Tasker(name = 't3', store = house.store, period = 0.125)
-    t4 = Tasker(name = 't4', store = house.store, period = 0.125)
-    t5 = Tasker(name = 't5', store = house.store, period = 0.5)
-    t6 = Tasker(name = 't6', store = house.store, period = 1.0)
-
-    house.actives = [t1,t6,t2,t5,t3,t4]
-
-    skedder = skedding.Skedder(name = "TestTasker", period = 0.125, real = real, houses = [house])
-    skedder.run()
-
-
-def TestProfile(real = False, verbose = False):
-    """Module Common self test
-
-
-
-    """
-    import cProfile
-    import pstats
-
-    import housing
-    reload(housing)
-    import skedding
-
-    housing.ClearRegistries()
-
-    print(housing.Registries)
-    print("")
-    print(housing.Registries["tasker"].Names)
-    print(housing.Registries["tasker"].Counter)
-    print("")
-
-    house = housing.House()
-
-    t1 = Tasker(name = 't1', store = house.store)
-    t2 = Tasker(name = 't2', store = house.store)
-    t3 = Tasker(name = 't3', store = house.store, period = 0.125)
-    t4 = Tasker(name = 't4', store = house.store, period = 0.125)
-    t5 = Tasker(name = 't5', store = house.store, period = 0.5)
-    t6 = Tasker(name = 't6', store = house.store, period = 1.0)
-
-    house.actives = [t1,t6,t2,t5,t3,t4]
-
-    skedder = skedding.Skedder(name = "TestSkedder", period = 0.125, real = real, houses = [house])
-    #skedder.run()
-    cProfile.runctx('skedder.run()',globals(),locals(), './test/profiles/skeddertest')
-
-    p = pstats.Stats('./test/profiles/skeddertest')
-    p.sort_stats('time').print_stats()
-    p.print_callers()
-    p.print_callees()
-
-
-if __name__ == "__main__":
-    Test()
+ResolveTasker = resolveTasker
